@@ -6,7 +6,7 @@
 
 #include "bridgewidget.h"
 #include "connectioneditordialog.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "ui_bridge.h"
 
 #include <QDBusPendingReply>
@@ -24,12 +24,12 @@ BridgeWidget::BridgeWidget(const QString &masterUuid, const QString &masterId, c
     , m_uuid(masterUuid)
     , m_id(masterId)
     , m_ui(new Ui::BridgeWidget)
+    , m_menu(new QMenu(this))
 {
     m_ui->setupUi(this);
 
     // Action buttons and menu
-    m_menu = new QMenu(this);
-    QAction *action = new QAction(i18n("Ethernet"), this);
+    auto action = new QAction(i18n("Ethernet"), this);
     action->setData(NetworkManager::ConnectionSettings::Wired);
     m_menu->addAction(action);
     action = new QAction(i18n("VLAN"), this);
@@ -103,9 +103,9 @@ QVariantMap BridgeWidget::setting() const
 
 void BridgeWidget::addBridge(QAction *action)
 {
-    qCDebug(PLASMA_NM) << "Adding bridged connection:" << action->data();
-    qCDebug(PLASMA_NM) << "Master UUID:" << m_uuid;
-    qCDebug(PLASMA_NM) << "Slave type:" << type();
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Adding bridged connection:" << action->data();
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Master UUID:" << m_uuid;
+    qCDebug(PLASMA_NM_EDITOR_LOG) << "Slave type:" << type();
 
     NetworkManager::ConnectionSettings::ConnectionType connectionType = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toInt());
     NetworkManager::ConnectionSettings::Ptr connectionSettings =
@@ -116,18 +116,14 @@ void BridgeWidget::addBridge(QAction *action)
     connectionSettings->setAutoconnect(false);
 
     QPointer<ConnectionEditorDialog> bridgeEditor = new ConnectionEditorDialog(connectionSettings);
+    bridgeEditor->setAttribute(Qt::WA_DeleteOnClose);
     connect(bridgeEditor.data(), &ConnectionEditorDialog::accepted, [bridgeEditor, this]() {
-        qCDebug(PLASMA_NM) << "Saving slave connection";
-        // qCDebug(PLASMA_NM) << bridgeEditor->setting();
+        qCDebug(PLASMA_NM_EDITOR_LOG) << "Saving slave connection";
+        // qCDebug(PLASMA_NM_EDITOR_LOG) << bridgeEditor->setting();
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bridgeEditor->setting());
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+        auto watcher = new QDBusPendingCallWatcher(reply, this);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &BridgeWidget::bridgeAddComplete);
     });
-    connect(bridgeEditor.data(), &ConnectionEditorDialog::finished, [bridgeEditor]() {
-        if (bridgeEditor) {
-            bridgeEditor->deleteLater();
-        }
-    });
     bridgeEditor->setModal(true);
     bridgeEditor->show();
 }
@@ -149,13 +145,13 @@ void BridgeWidget::bridgeAddComplete(QDBusPendingCallWatcher *watcher)
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(reply.value().path());
         if (connection && connection->settings()->master() == m_uuid) {
             const QString label =
-                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->bridges);
+                QStringLiteral("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
+            auto slaveItem = new QListWidgetItem(label, m_ui->bridges);
             slaveItem->setData(Qt::UserRole, connection->uuid());
             slotWidgetChanged();
         }
     } else {
-        qCWarning(PLASMA_NM) << "Bridged connection not added:" << reply.error().message();
+        qCWarning(PLASMA_NM_EDITOR_LOG) << "Bridged connection not added:" << reply.error().message();
     }
 }
 
@@ -169,17 +165,13 @@ void BridgeWidget::editBridge()
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
 
     if (connection) {
-        qCDebug(PLASMA_NM) << "Editing bridged connection" << currentItem->text() << uuid;
+        qCDebug(PLASMA_NM_EDITOR_LOG) << "Editing bridged connection" << currentItem->text() << uuid;
         QPointer<ConnectionEditorDialog> bridgeEditor = new ConnectionEditorDialog(connection->settings());
+        bridgeEditor->setAttribute(Qt::WA_DeleteOnClose);
         connect(bridgeEditor.data(), &ConnectionEditorDialog::accepted, [connection, bridgeEditor, this]() {
             connection->update(bridgeEditor->setting());
             connect(connection.data(), &NetworkManager::Connection::updated, this, &BridgeWidget::populateBridges);
         });
-        connect(bridgeEditor.data(), &ConnectionEditorDialog::finished, [bridgeEditor]() {
-            if (bridgeEditor) {
-                bridgeEditor->deleteLater();
-            }
-        });
         bridgeEditor->setModal(true);
         bridgeEditor->show();
     }
@@ -195,7 +187,7 @@ void BridgeWidget::deleteBridge()
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
 
     if (connection) {
-        // qCDebug(PLASMA_NM) << "About to delete bridged connection" << currentItem->text() << uuid;
+        // qCDebug(PLASMA_NM_EDITOR_LOG) << "About to delete bridged connection" << currentItem->text() << uuid;
         if (KMessageBox::questionYesNo(this,
                                        i18n("Do you want to remove the connection '%1'?", connection->name()),
                                        i18n("Remove Connection"),
@@ -224,8 +216,8 @@ void BridgeWidget::populateBridges()
                         (!m_id.isEmpty() && master == m_id)); // by-name
         if (isSlave && (settings->slaveType() == type())) {
             const QString label =
-                QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-            QListWidgetItem *slaveItem = new QListWidgetItem(label, m_ui->bridges);
+                QStringLiteral("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
+            auto slaveItem = new QListWidgetItem(label, m_ui->bridges);
             slaveItem->setData(Qt::UserRole, connection->uuid());
         }
     }
